@@ -8,14 +8,21 @@ class BadFormatError(InvalidData):
     pass
 
 class LiftoverFailure(InvalidData):
-    def __init__(self,chrom,pos):
-        msg = 'Failed to liftover %s %s' %(chrom,str(pos))
-        super().__init__(msg)
-        
+    pass
+
 class FileIntegrityError(Exception):
     def __init__(self, path):
         super().__init__(path)
         
 class CravatProfileException():
     def __init__(self, msg):
-        super().__init__(msg)
\ No newline at end of file
+        super().__init__(msg)
+
+class ExpectedException (Exception):
+    pass
+
+class KillInstallException (Exception):
+    pass
+
+class InvalidReporter (Exception):
+    pass
